@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,13 +27,15 @@
 #include <math.h>
 
 #include <cfg.h>
+#include <graph.h>
+#include <parray.h>
 #include <plog.h>
 #include <psensor.h>
 
 /* horizontal padding */
-const int GRAPH_H_PADDING = 4;
+static const int GRAPH_H_PADDING = 4;
 /* vertical padding */
-const int GRAPH_V_PADDING = 4;
+static const int GRAPH_V_PADDING = 4;
 
 bool is_smooth_curves_enabled;
 
@@ -72,6 +74,29 @@ static void update_theme(GtkWidget *w)
 				    &theme_fg_color);
 }
 
+static struct psensor **list_filter_graph_enabled(struct psensor **sensors)
+{
+	int n, i;
+	struct psensor **result, **cur, *s;
+
+	if (!sensors)
+		return NULL;
+
+	n = psensor_list_size(sensors);
+	result = malloc((n+1) * sizeof(struct psensor *));
+
+	for (cur = sensors, i = 0; *cur; cur++) {
+		s = *cur;
+
+		if (config_is_sensor_graph_enabled(s->id))
+			result[i++] = s;
+	}
+
+	result[i] = NULL;
+
+	return result;
+}
+
 /* Return the end time of the graph i.e. the more recent measure.  If
  * no measure are available, return 0.
  * If Bezier curves are used return the measure n-3 to avoid to
@@ -223,7 +248,7 @@ static double dashes[] = {
 	1.0,		/* ink */
 	2.0,		/* skip */
 };
-static int ndash = sizeof(dashes) / sizeof(dashes[0]);
+static int ndash = ARRAY_SIZE(dashes);
 
 static void draw_background_lines(cairo_t *cr,
 				  int min, int max,
@@ -265,7 +290,7 @@ static void draw_background_lines(cairo_t *cr,
 	cairo_stroke(cr);
 
 	/* back to normal line style */
-	cairo_set_dash(cr, 0, 0, 0);
+	cairo_set_dash(cr, NULL, 0, 0);
 }
 
 /* Keys: sensor identifier.
@@ -286,6 +311,7 @@ static void draw_sensor_smooth_curve(struct psensor *s,
 	int i, dt, vdt, j, k, found;
 	double x[4], y[4], v;
 	time_t t, t0, *stimes;
+	GdkRGBA *color;
 
 	if (!times)
 		times = g_hash_table_new_full(g_str_hash,
@@ -295,15 +321,19 @@ static void draw_sensor_smooth_curve(struct psensor *s,
 
 	stimes = g_hash_table_lookup(times, s->id);
 
+	color = config_get_sensor_color(s->id);
+
 	cairo_set_source_rgb(cr,
-			     s->color->red,
-			     s->color->green,
-			     s->color->blue);
+			     color->red,
+			     color->green,
+			     color->blue);
+	gdk_rgba_free(color);
 
 	/* search the index of the first measure used as a start point
 	 * of a Bezier curve. The start and end points of the Bezier
 	 * curves must be preserved to ensure the same overall shape
-	 * of the graph. */
+	 * of the graph.
+	 */
 	i = 0;
 	if (stimes) {
 		while (i < s->values_max_length) {
@@ -388,11 +418,14 @@ static void draw_sensor_curve(struct psensor *s,
 {
 	int first, i, t, dt, vdt;
 	double v, x, y;
+	GdkRGBA *color;
 
+	color = config_get_sensor_color(s->id);
 	cairo_set_source_rgb(cr,
-			     s->color->red,
-			     s->color->green,
-			     s->color->blue);
+			     color->red,
+			     color->green,
+			     color->blue);
+	gdk_rgba_free(color);
 
 	dt = et - bt;
 	first = 1;
@@ -448,14 +481,13 @@ graph_update(struct psensor **sensors,
 	double min_rpm, max_rpm, mint, maxt, min, max;
 	char *strmin, *strmax;
 	/* horizontal and vertical offset of the graph */
-	int g_xoff, g_yoff, no_graphs;
+	int g_xoff, g_yoff, no_graphs, use_celsius;
 	cairo_surface_t *cst;
 	cairo_t *cr, *cr_pixmap;
 	char *str_btime, *str_etime;
 	cairo_text_extents_t te_btime, te_etime, te_max, te_min;
 	struct psensor **sensor_cur, **enabled_sensors;
 	GtkAllocation galloc;
-	GtkStyleContext *style_ctx;
 	struct graph_info info;
 
 	if (!gtk_widget_is_drawable(w_graph))
@@ -464,20 +496,21 @@ graph_update(struct psensor **sensors,
 	if (!style)
 		update_theme(window);
 
-	enabled_sensors = psensor_list_filter_graph_enabled(sensors);
+	enabled_sensors = list_filter_graph_enabled(sensors);
 
 	min_rpm = get_min_rpm(enabled_sensors);
 	max_rpm = get_max_rpm(enabled_sensors);
 
+	if (config_get_temperature_unit() == CELSIUS)
+		use_celsius = 1;
+	else
+		use_celsius = 0;
+
 	mint = get_min_temp(enabled_sensors);
-	strmin = psensor_value_to_str(SENSOR_TYPE_TEMP,
-				      mint,
-				      config->temperature_unit == CELSIUS);
+	strmin = psensor_value_to_str(SENSOR_TYPE_TEMP, mint, use_celsius);
 
 	maxt = get_max_temp(enabled_sensors);
-	strmax = psensor_value_to_str(SENSOR_TYPE_TEMP,
-				      maxt,
-				      config->temperature_unit == CELSIUS);
+	strmax = psensor_value_to_str(SENSOR_TYPE_TEMP, maxt, use_celsius);
 
 	et = get_graph_end_time_s(enabled_sensors);
 	bt = get_graph_begin_time_s(config, et);
