@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,7 +30,8 @@
 #include <pio.h>
 
 /* Directory separator is \ when cross-compiling for MS Windows
-   systems */
+ * systems
+ */
 #if defined(__MINGW32__)
 #define DIRSEP ('\\')
 #else
@@ -63,7 +64,7 @@ int is_file(const char *path)
 	return 0;
 }
 
-char *dir_normalize(const char *dpath)
+static char *dir_normalize(const char *dpath)
 {
 	char *npath;
 	int n;
