@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,7 +43,7 @@ void log_open(const char *path)
 		log_printf(LOG_ERR, _("Cannot open log file: %s"), path);
 }
 
-void log_close()
+void log_close(void)
 {
 	if (!file)
 		return;
