@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,53 +28,34 @@
 
 #include <gtk/gtk.h>
 
-#include "config.h"
+#include <config.h>
 
-#include "cfg.h"
+#include <amd.h>
+#include <cfg.h>
+#include <graph.h>
 #include <hdd.h>
-#include "psensor.h"
-#include "graph.h"
-#include "ui.h"
-#include "ui_sensorlist.h"
-#include "ui_color.h"
-#include "lmsensor.h"
-#include "notify_cmd.h"
-#include <pmutex.h>
-#include <pudisks2.h>
-#include "slog.h"
-#include "ui_pref.h"
-#include "ui_graph.h"
-#include "ui_status.h"
-
-#ifdef HAVE_UNITY
-#include "ui_unity.h"
-#endif
-
-#ifdef HAVE_NVIDIA
-#include "nvidia.h"
-#endif
-
-#ifdef HAVE_LIBATIADL
-#include "amd.h"
-#endif
-
-#ifdef HAVE_REMOTE_SUPPORT
-#include "rsensor.h"
-#endif
-
-#include "ui_appindicator.h"
-
-#ifdef HAVE_LIBNOTIFY
-#include "ui_notify.h"
-#endif
-
-#ifdef HAVE_GTOP
+#include <lmsensor.h>
+#include <notify_cmd.h>
+#include <nvidia.h>
 #include <pgtop2.h>
-#endif
+#include <pmutex.h>
+#include <psensor.h>
+#include <pudisks2.h>
+#include <rsensor.h>
+#include <slog.h>
+#include <ui.h>
+#include <ui_appindicator.h>
+#include <ui_color.h>
+#include <ui_graph.h>
+#include <ui_notify.h>
+#include <ui_pref.h>
+#include <ui_sensorlist.h>
+#include <ui_status.h>
+#include <ui_unity.h>
 
 static const char *program_name;
 
-static void print_version()
+static void print_version(void)
 {
 	printf("psensor %s\n", VERSION);
 	printf(_("Copyright (C) %s jeanfi@gmail.com\n"
@@ -86,7 +67,7 @@ static void print_version()
 	       "2010-2014");
 }
 
-static void print_help()
+static void print_help(void)
 {
 	printf(_("Usage: %s [OPTION]...\n"), program_name);
 
@@ -155,25 +136,13 @@ static void *update_measures(void *data)
 		update_psensor_values_size(sensors, cfg);
 
 		lmsensor_psensor_list_update(sensors);
-#ifdef HAVE_REMOTE_SUPPORT
-		remote_psensor_list_update(sensors);
-#endif
-#ifdef HAVE_NVIDIA
-		nvidia_psensor_list_update(sensors);
-#endif
-#ifdef HAVE_LIBATIADL
-		amd_psensor_list_update(sensors);
-#endif
-#ifdef HAVE_LIBUDISKS2
-		udisks2_psensor_list_update(sensors);
-#endif
-#ifdef HAVE_GTOP
-		gtop2_psensor_list_update(sensors);
-#endif
-#ifdef HAVE_ATASMART
-		atasmart_psensor_list_update(sensors);
-#endif
 
+		remote_psensor_list_update(sensors);
+		nvidia_psensor_list_update(sensors);
+		amd_psensor_list_update(sensors);
+		udisks2_psensor_list_update(sensors);
+		gtop2_psensor_list_update(sensors);
+		atasmart_psensor_list_update(sensors);
 		hddtemp_psensor_list_update(sensors);
 
 		psensor_log_measures(sensors);
@@ -188,30 +157,30 @@ static void *update_measures(void *data)
 
 static void indicators_update(struct ui_psensor *ui)
 {
-	struct psensor **sensor_cur = ui->sensors;
-	unsigned int attention = 0;
+	struct psensor **ss, *s;
+	bool attention;
 
-	while (*sensor_cur) {
-		struct psensor *s = *sensor_cur;
+	attention = false;
+	ss = ui->sensors;
+	while (*ss) {
+		s = *ss;
 
-		if (s->alarm_enabled && s->alarm_raised) {
-			attention = 1;
+		if (s->alarm_raised && config_get_sensor_alarm_enabled(s->id)) {
+			attention = true;
 			break;
 		}
 
-		sensor_cur++;
+		ss++;
 	}
 
-#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
 	if (is_appindicator_supported())
 		ui_appindicator_update(ui, attention);
-#endif
 
 	if (is_status_supported())
 		ui_status_update(ui, attention);
 }
 
-gboolean ui_refresh_thread(gpointer data)
+static gboolean ui_refresh_thread(gpointer data)
 {
 	struct config *cfg;
 	gboolean ret;
@@ -222,18 +191,14 @@ gboolean ui_refresh_thread(gpointer data)
 
 	pmutex_lock(&ui->sensors_mutex);
 
-	graph_update(ui->sensors, ui->w_graph, ui->config, ui->main_window);
+	graph_update(ui->sensors, ui_get_graph(), ui->config, ui->main_window);
 
 	ui_sensorlist_update(ui, 0);
 
 	if (is_appindicator_supported() || is_status_supported())
 		indicators_update(ui);
 
-#ifdef HAVE_UNITY
-	ui_unity_launcher_entry_update(ui->sensors,
-				       !cfg->unity_launcher_count_disabled,
-				       cfg->temperature_unit == CELSIUS);
-#endif
+	ui_unity_launcher_entry_update(ui->sensors);
 
 	if (ui->graph_update_interval != cfg->graph_update_interval) {
 		ui->graph_update_interval = cfg->graph_update_interval;
@@ -251,82 +216,46 @@ gboolean ui_refresh_thread(gpointer data)
 
 static void cb_alarm_raised(struct psensor *sensor, void *data)
 {
-#ifdef HAVE_LIBNOTIFY
-	if (sensor->alarm_enabled)
+	if (config_get_sensor_alarm_enabled(sensor->id)) {
 		ui_notify(sensor, (struct ui_psensor *)data);
-#endif
-
-	notify_cmd(sensor);
-}
-
-static void associate_colors(struct psensor **sensors)
-{
-	GdkRGBA rgba;
-	/* copied from the default colors of the gtk color color
-	 * chooser. */
-	const char *default_colors[27] = {
-		"#ef2929",  /* Scarlet Red */
-		"#fcaf3e",  /* Orange */
-		"#fce94f",  /* Butter */
-		"#8ae234",  /* Chameleon */
-		"#729fcf",  /* Sky Blue */
-		"#ad7fa8",  /* Plum */
-		"#e9b96e",  /* Chocolate */
-		"#888a85",  /* Aluminum 1 */
-		"#eeeeec",  /* Aluminum 2 */
-		"#cc0000",
-		"#f57900",
-		"#edd400",
-		"#73d216",
-		"#3465a4",
-		"#75507b",
-		"#c17d11",
-		"#555753",
-		"#d3d7cf",
-		"#a40000",
-		"#ce5c00",
-		"#c4a000",
-		"#4e9a06",
-		"#204a87",
-		"#5c3566",
-		"#8f5902",
-		"#2e3436",
-		"#babdb6"
-	};
-	int i;
-	struct psensor **cur;
-	struct color c;
-
-	for (cur = sensors, i = 0; *cur; cur++, i++) {
-		gdk_rgba_parse(&rgba, default_colors[i % 27]);
-		c.red = rgba.red;
-		c.green = rgba.green;
-		c.blue = rgba.blue;
-
-		(*cur)->color = config_get_sensor_color((*cur)->id, &c);
+		notify_cmd(sensor);
 	}
 }
 
 static void
 associate_cb_alarm_raised(struct psensor **sensors, struct ui_psensor *ui)
 {
-	struct psensor **sensor_cur = sensors;
+	bool ret;
+	struct psensor *s;
+	double high_temp;
 
-	while (*sensor_cur) {
-		struct psensor *s = *sensor_cur;
+	high_temp = config_get_default_high_threshold_temperature();
+
+	while (*sensors) {
+		s = *sensors;
 
 		s->cb_alarm_raised = cb_alarm_raised;
 		s->cb_alarm_raised_data = ui;
 
-		s->alarm_high_threshold
-			= config_get_sensor_alarm_high_threshold(s->id);
-		s->alarm_low_threshold
-			= config_get_sensor_alarm_low_threshold(s->id);
+		ret = config_get_sensor_alarm_high_threshold
+			(s->id, &s->alarm_high_threshold);
 
-		s->alarm_enabled
-			    = config_get_sensor_alarm_enabled(s->id);
+		if (!ret) {
+			if (s->max == UNKNOWN_DBL_VALUE) {
+				if (s->type & SENSOR_TYPE_TEMP)
+					s->alarm_high_threshold = high_temp;
+			} else {
+				s->alarm_high_threshold = s->max;
+			}
+		}
 
-		sensor_cur++;
+		ret = config_get_sensor_alarm_low_threshold
+			(s->id, &s->alarm_low_threshold);
+
+		if (!ret && s->min != UNKNOWN_DBL_VALUE)
+			s->alarm_low_threshold = s->min;
+
+		sensors++;
 	}
 }
 
@@ -338,8 +267,6 @@ static void associate_preferences(struct psensor **sensors)
 		char *n;
 		struct psensor *s = *sensor_cur;
 
-		s->graph_enabled = config_is_sensor_graph_enabled(s->id);
-
 		n = config_get_sensor_name(s->id);
 
 		if (n) {
@@ -347,13 +274,11 @@ static void associate_preferences(struct psensor **sensors)
 			s->name = n;
 		}
 
-		s->appindicator_enabled = config_is_appindicator_enabled(s->id);
-
 		sensor_cur++;
 	}
 }
 
-static void log_init()
+static void log_init(void)
 {
 	const char *dir;
 	char *path;
@@ -372,12 +297,12 @@ static void log_init()
 }
 
 static struct option long_options[] = {
-	{"version", no_argument, 0, 'v'},
-	{"help", no_argument, 0, 'h'},
-	{"url", required_argument, 0, 'u'},
-	{"debug", required_argument, 0, 'd'},
-	{"new-instance", no_argument, 0, 'n'},
-	{0, 0, 0, 0}
+	{"version", no_argument, NULL, 'v'},
+	{"help", no_argument, NULL, 'h'},
+	{"url", required_argument, NULL, 'u'},
+	{"debug", required_argument, NULL, 'd'},
+	{"new-instance", no_argument, NULL, 'n'},
+	{NULL, 0, NULL, 0}
 };
 
 static gboolean initial_window_show(gpointer data)
@@ -402,7 +327,7 @@ static gboolean initial_window_show(gpointer data)
 	return FALSE;
 }
 
-static void log_glib_info()
+static void log_glib_info(void)
 {
 	log_debug("Compiled with GLib %d.%d.%d",
 		  GLIB_MAJOR_VERSION,
@@ -430,22 +355,14 @@ static void cleanup(struct ui_psensor *ui)
 
 	log_debug("Cleanup...");
 
-#ifdef HAVE_NVIDIA
 	nvidia_cleanup();
-#endif
-#ifdef HAVE_LIBATIADL
 	amd_cleanup();
-#endif
-#ifdef HAVE_REMOTE_SUPPORT
 	rsensor_cleanup();
-#endif
 
 	psensor_list_free(ui->sensors);
 	ui->sensors = NULL;
 
-#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
 	ui_appindicator_cleanup();
-#endif
 
 	ui_status_cleanup();
 
@@ -466,14 +383,14 @@ static struct psensor **create_sensors_list(const char *url)
 	struct psensor **sensors;
 
 	if (url) {
-#ifdef HAVE_REMOTE_SUPPORT
-		rsensor_init();
-		sensors = get_remote_sensors(url, 600);
-#else
-		log_err(_("Psensor has not been compiled with remote "
-			  "sensor support."));
-		exit(EXIT_FAILURE);
-#endif
+		if (rsensor_is_supported()) {
+			rsensor_init();
+			sensors = get_remote_sensors(url, 600);
+		} else {
+			log_err(_("Psensor has not been compiled with remote "
+				  "sensor support."));
+			exit(EXIT_FAILURE);
+		}
 	} else {
 		sensors = malloc(sizeof(struct psensor *));
 		*sensors = NULL;
@@ -484,31 +401,23 @@ static struct psensor **create_sensors_list(const char *url)
 		if (config_is_hddtemp_enabled())
 			hddtemp_psensor_list_append(&sensors, 600);
 
-#ifdef HAVE_ATASMART
 		if (config_is_libatasmart_enabled())
 			atasmart_psensor_list_append(&sensors, 600);
-#endif
 
-#ifdef HAVE_NVIDIA
 		if (config_is_nvctrl_enabled())
 			nvidia_psensor_list_append(&sensors, 600);
-#endif
-#ifdef HAVE_LIBATIADL
+
 		if (config_is_atiadlsdk_enabled())
 			amd_psensor_list_append(&sensors, 600);
-#endif
-#ifdef HAVE_GTOP
+
 		if (config_is_gtop2_enabled())
 			gtop2_psensor_list_append(&sensors, 600);
-#endif
-#ifdef HAVE_LIBUDISKS2
+
 		if (config_is_udisks2_enabled())
 			udisks2_psensor_list_append(&sensors, 600);
-#endif
 	}
 
 	associate_preferences(sensors);
-	associate_colors(sensors);
 
 	return sensors;
 }
@@ -589,17 +498,6 @@ int main(int argc, char **argv)
 	g_thread_init(NULL);
 #endif
 
-#ifdef HAVE_APPINDICATOR_029
-	/* gdk_thread_enter/leave only used to workaround mutex bug
-	 * of appindicator < 0.2.9, so do not call gdk_threads_init
-	 * if useless. Calling this function leads to
-	 * crash "Attempt to unlock mutex that was not locked" with
-	 * GLib 2.41.2 (new checking) probably due to bugs in GTK
-	 * itself.
-	 */
-	gdk_threads_init();
-#endif
-
 	gtk_init(NULL, NULL);
 
 	pmutex_init(&ui.sensors_mutex);
@@ -615,10 +513,8 @@ int main(int argc, char **argv)
 			      &ui.sensors_mutex,
 			      config_get_slog_interval());
 
-#if !defined(HAVE_APPINDICATOR) && !defined(HAVE_APPINDICATOR_029)
 	ui_status_init(&ui);
 	ui_status_set_visible(1);
-#endif
 
 	/* main window */
 	ui_window_create(&ui);
@@ -634,9 +530,8 @@ int main(int argc, char **argv)
 
 	g_timeout_add(1000 * ui.graph_update_interval, ui_refresh_thread, &ui);
 
-#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
 	ui_appindicator_init(&ui);
-#endif
+	ui_unity_init();
 
 	gdk_notify_startup_complete();
 
@@ -651,8 +546,6 @@ int main(int argc, char **argv)
 	else
 		initial_window_show(&ui);
 
-	log_debug("translators: %s\n", _("translator-credits"));
-
 	/* main loop */
 	gtk_main();
 
