@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,15 +18,139 @@
  */
 #include <stdlib.h>
 
-#include "cfg.h"
-#include "slog.h"
-#include "ui.h"
-#include "ui_graph.h"
-#include "ui_pref.h"
-#include "ui_sensorpref.h"
-#include "ui_sensorlist.h"
-#include "ui_status.h"
-#include "ui_appindicator.h"
+#include <cfg.h>
+#include <slog.h>
+#include <ui.h>
+#include <ui_appindicator.h>
+#include <ui_graph.h>
+#include <ui_pref.h>
+#include <ui_sensorlist.h>
+#include <ui_sensorpref.h>
+#include <ui_status.h>
+
+static GtkWidget *w_sensors_scrolled_tree;
+static GtkWidget *w_graph;
+static GtkContainer *w_sensor_box;
+static GtkContainer *w_main_box;
+
+static void update_layout(void)
+{
+	enum sensorlist_position sensorlist_pos;
+
+	g_object_ref(w_sensors_scrolled_tree);
+	g_object_ref(w_graph);
+
+	gtk_container_remove(w_sensor_box,
+			     w_sensors_scrolled_tree);
+
+	gtk_container_remove(w_sensor_box, w_graph);
+
+	gtk_container_remove(w_main_box, GTK_WIDGET(w_sensor_box));
+
+	sensorlist_pos = config_get_sensorlist_position();
+	if (sensorlist_pos == SENSORLIST_POSITION_RIGHT
+	    || sensorlist_pos == SENSORLIST_POSITION_LEFT)
+		w_sensor_box
+			= GTK_CONTAINER(gtk_paned_new
+					(GTK_ORIENTATION_HORIZONTAL));
+	else
+		w_sensor_box
+			= GTK_CONTAINER(gtk_paned_new
+					(GTK_ORIENTATION_VERTICAL));
+
+	gtk_box_pack_end(GTK_BOX(w_main_box),
+			 GTK_WIDGET(w_sensor_box), TRUE, TRUE, 2);
+
+	if (sensorlist_pos == SENSORLIST_POSITION_RIGHT
+	    || sensorlist_pos == SENSORLIST_POSITION_BOTTOM) {
+		gtk_paned_pack1(GTK_PANED(w_sensor_box), w_graph, TRUE, TRUE);
+		gtk_paned_pack2(GTK_PANED(w_sensor_box),
+				w_sensors_scrolled_tree,
+				FALSE,
+				TRUE);
+	} else {
+		gtk_paned_pack1(GTK_PANED(w_sensor_box),
+				w_sensors_scrolled_tree,
+				FALSE,
+				TRUE);
+		gtk_paned_pack2(GTK_PANED(w_sensor_box), w_graph, TRUE, TRUE);
+	}
+
+	g_object_unref(w_sensors_scrolled_tree);
+	g_object_unref(w_graph);
+
+	gtk_widget_show_all(GTK_WIDGET(w_sensor_box));
+}
+
+static void set_decoration(GtkWindow *win)
+{
+	gtk_window_set_decorated(win, config_is_window_decoration_enabled());
+}
+
+static void set_keep_below(GtkWindow *win)
+{
+	gtk_window_set_keep_below(win, config_is_window_keep_below_enabled());
+}
+
+static void set_menu_bar_enabled(GtkWidget *bar)
+{
+	if (config_is_menu_bar_enabled())
+		gtk_widget_show(bar);
+	else
+		gtk_widget_hide(bar);
+}
+
+static void
+decoration_changed_cbk(GSettings *settings, gchar *key, gpointer data)
+{
+	set_decoration(GTK_WINDOW(data));
+}
+
+static void
+keep_below_changed_cbk(GSettings *settings, gchar *key, gpointer data)
+{
+	set_keep_below(GTK_WINDOW(data));
+}
+
+static void
+menu_bar_changed_cbk(GSettings *settings, gchar *key, gpointer data)
+{
+	set_menu_bar_enabled(GTK_WIDGET(data));
+}
+
+static void
+sensorlist_position_changed_cbk(GSettings *settings, gchar *key, gpointer data)
+{
+	update_layout();
+}
+
+static void connect_cbks(GtkWindow *win, GtkWidget *menu_bar)
+{
+	log_fct_enter();
+
+	g_signal_connect_after(config_get_GSettings(),
+			       "changed::interface-window-decoration-disabled",
+			       G_CALLBACK(decoration_changed_cbk),
+			       win);
+
+	g_signal_connect_after(config_get_GSettings(),
+			       "changed::interface-window-keep-below-enabled",
+			       G_CALLBACK(keep_below_changed_cbk),
+			       win);
+
+	g_signal_connect_after(config_get_GSettings(),
+			       "changed::interface-menu-bar-disabled",
+			       G_CALLBACK(menu_bar_changed_cbk),
+			       menu_bar);
+
+	g_signal_connect_after(config_get_GSettings(),
+			       "changed::interface-sensorlist-position",
+			       G_CALLBACK(sensorlist_position_changed_cbk),
+			       menu_bar);
+
+
+	log_fct_exit();
+}
 
 static void save_window_pos(struct ui_psensor *ui)
 {
@@ -53,7 +177,7 @@ static void save_window_pos(struct ui_psensor *ui)
 		log_debug("Window size: %d %d", cfg->window_w, cfg->window_h);
 
 		cfg->window_divider_pos
-			= gtk_paned_get_position(GTK_PANED(ui->sensor_box));
+			= gtk_paned_get_position(GTK_PANED(w_sensor_box));
 
 		config_save(cfg);
 	}
@@ -76,18 +200,20 @@ on_delete_event_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 	return TRUE;
 }
 
-void ui_show_about_dialog()
+void ui_show_about_dialog(GtkWindow *parent)
 {
 	static const char *const authors[] = { "jeanfi@gmail.com", NULL };
 
+	log_fct("parent=%p", parent);
+
 	gtk_show_about_dialog
-		(NULL,
+		(parent,
 		 "authors", authors,
 		 "comments",
 		 _("Psensor is a GTK+ application for monitoring hardware "
 		   "sensors"),
 		 "copyright",
-		 _("Copyright(c) 2010-2014 jeanfi@gmail.com"),
+		 _("Copyright(c) 2010-2016 jeanfi@gmail.com"),
 #if GTK_CHECK_VERSION(3, 12, 0)
 		 "license-type", GTK_LICENSE_GPL_2_0,
 #endif
@@ -101,9 +227,21 @@ void ui_show_about_dialog()
 		 NULL);
 }
 
-void ui_cb_about(GtkMenuItem *mi, gpointer data)
+void ui_cb_about(GtkAction *a, gpointer data)
 {
-	ui_show_about_dialog();
+	struct ui_psensor *ui;
+	GtkWidget *parent;
+
+	ui = (struct ui_psensor *)data;
+
+	log_fct("ui=%p", ui);
+
+	if (ui)
+		parent = ui->main_window;
+	else
+		parent = NULL;
+
+	ui_show_about_dialog(GTK_WINDOW(parent));
 }
 
 void ui_cb_menu_quit(GtkMenuItem *mi, gpointer data)
@@ -179,7 +317,7 @@ static void slog_enabled_cbk(void *data)
 
 void ui_window_create(struct ui_psensor *ui)
 {
-	GtkWidget *window;
+	GtkWidget *window, *menu_bar;
 	GdkPixbuf *icon;
 	GtkIconTheme *icon_theme;
 	struct config *cfg;
@@ -187,6 +325,8 @@ void ui_window_create(struct ui_psensor *ui)
 	GtkBuilder *builder;
 	GError *error;
 
+	log_fct("ui=%p", ui);
+
 	builder = gtk_builder_new();
 
 	error = NULL;
@@ -225,50 +365,42 @@ void ui_window_create(struct ui_psensor *ui)
 	g_signal_connect(window,
 			 "delete_event", G_CALLBACK(on_delete_event_cb), ui);
 
-	gtk_window_set_decorated(GTK_WINDOW(window),
-				 cfg->window_decoration_enabled);
+	set_decoration(GTK_WINDOW(window));
+	set_keep_below(GTK_WINDOW(window));
 
-	gtk_window_set_keep_below(GTK_WINDOW(window),
-				  cfg->window_keep_below_enabled);
-
-	ui->menu_bar = GTK_WIDGET(gtk_builder_get_object(builder, "menu_bar"));
-	ui->main_box = GTK_WIDGET(gtk_builder_get_object(builder, "main_box"));
+	menu_bar = GTK_WIDGET(gtk_builder_get_object(builder, "menu_bar"));
+	w_main_box = GTK_CONTAINER(gtk_builder_get_object(builder, "main_box"));
 	ui->popup_menu = GTK_WIDGET(gtk_builder_get_object(builder,
 							   "popup_menu"));
 	g_object_ref(G_OBJECT(ui->popup_menu));
 	ui->main_window = window;
-	ui->w_graph = GTK_WIDGET(gtk_builder_get_object(builder,
-							"graph"));
+	w_graph = GTK_WIDGET(gtk_builder_get_object(builder, "graph"));
 	ui_graph_create(ui);
 
-	ui->sensor_box = GTK_PANED(gtk_builder_get_object(builder,
-							  "sensor_box"));
+	w_sensor_box = GTK_CONTAINER(gtk_builder_get_object(builder,
+							    "sensor_box"));
 	ui->sensors_store = GTK_LIST_STORE(gtk_builder_get_object
 					   (builder, "sensors_store"));
 	ui->sensors_tree = GTK_TREE_VIEW(gtk_builder_get_object
 					 (builder, "sensors_tree"));
-	ui->sensors_scrolled_tree
-		= GTK_SCROLLED_WINDOW(gtk_builder_get_object
-				      (builder, "sensors_scrolled_tree"));
+	w_sensors_scrolled_tree
+		= GTK_WIDGET(gtk_builder_get_object
+			     (builder, "sensors_scrolled_tree"));
 
 	ui_sensorlist_create(ui);
 
+	connect_cbks(GTK_WINDOW(window), menu_bar);
+
 	log_debug("ui_window_create(): show_all");
-	gtk_widget_show_all(ui->main_box);
+	update_layout();
+	gtk_widget_show_all(GTK_WIDGET(w_main_box));
+	set_menu_bar_enabled(menu_bar);
 
 	g_object_unref(G_OBJECT(builder));
 
 	log_debug("ui_window_create() ends");
 }
 
-static void menu_bar_show(unsigned int show, struct ui_psensor *ui)
-{
-	if (show)
-		gtk_widget_show(ui->menu_bar);
-	else
-		gtk_widget_hide(ui->menu_bar);
-}
-
 void ui_window_update(struct ui_psensor *ui)
 {
 	struct config *cfg;
@@ -277,55 +409,10 @@ void ui_window_update(struct ui_psensor *ui)
 
 	cfg = ui->config;
 
-	g_object_ref(GTK_WIDGET(ui->sensors_scrolled_tree));
-	g_object_ref(GTK_WIDGET(ui->w_graph));
-
-	gtk_container_remove(GTK_CONTAINER(ui->sensor_box),
-			     GTK_WIDGET(ui->sensors_scrolled_tree));
-
-	gtk_container_remove(GTK_CONTAINER(ui->sensor_box), ui->w_graph);
-
-	gtk_container_remove(GTK_CONTAINER(ui->main_box),
-			     GTK_WIDGET(ui->sensor_box));
-
-	if (cfg->sensorlist_position == SENSORLIST_POSITION_RIGHT
-	    || cfg->sensorlist_position == SENSORLIST_POSITION_LEFT)
-		ui->sensor_box
-			= GTK_PANED(gtk_paned_new(GTK_ORIENTATION_HORIZONTAL));
-	else
-		ui->sensor_box
-			= GTK_PANED(gtk_paned_new(GTK_ORIENTATION_VERTICAL));
-
-	gtk_box_pack_end(GTK_BOX(ui->main_box),
-			 GTK_WIDGET(ui->sensor_box), TRUE, TRUE, 2);
-
-	if (cfg->sensorlist_position == SENSORLIST_POSITION_RIGHT
-	    || cfg->sensorlist_position == SENSORLIST_POSITION_BOTTOM) {
-		gtk_paned_pack1(ui->sensor_box,
-				GTK_WIDGET(ui->w_graph), TRUE, TRUE);
-		gtk_paned_pack2(ui->sensor_box,
-				GTK_WIDGET(ui->sensors_scrolled_tree),
-				FALSE, TRUE);
-	} else {
-		gtk_paned_pack1(ui->sensor_box,
-				GTK_WIDGET(ui->sensors_scrolled_tree),
-				FALSE, TRUE);
-		gtk_paned_pack2(ui->sensor_box,
-				GTK_WIDGET(ui->w_graph), TRUE, TRUE);
-	}
-
 	if (cfg->window_restore_enabled)
-		gtk_paned_set_position(ui->sensor_box, cfg->window_divider_pos);
+		gtk_paned_set_position(GTK_PANED(w_sensor_box),
+				       cfg->window_divider_pos);
 
-	g_object_unref(GTK_WIDGET(ui->sensors_scrolled_tree));
-	g_object_unref(GTK_WIDGET(ui->w_graph));
-
-	gtk_widget_show_all(GTK_WIDGET(ui->sensor_box));
-
-	if (cfg->menu_bar_disabled)
-		menu_bar_show(0, ui);
-	else
-		menu_bar_show(1, ui);
 }
 
 void ui_window_show(struct ui_psensor *ui)
@@ -349,11 +436,11 @@ static int cmp_sensors(const void *p1, const void *p2)
 	return pos1 - pos2;
 }
 
-struct psensor **ui_get_sensors_ordered_by_position(const struct ui_psensor *ui)
+struct psensor **ui_get_sensors_ordered_by_position(struct psensor **sensors)
 {
 	struct psensor **result;
 
-	result = psensor_list_copy(ui->sensors);
+	result = psensor_list_copy(sensors);
 	qsort(result,
 	      psensor_list_size(result),
 	      sizeof(struct psensor *),
@@ -361,3 +448,8 @@ struct psensor **ui_get_sensors_ordered_by_position(const struct ui_psensor *ui)
 
 	return result;
 }
+
+GtkWidget *ui_get_graph(void)
+{
+	return w_graph;
+}
