@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,7 +26,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#if defined(HAVE_APPINDICATOR) || defined(HAVE_APPINDICATOR_029)
+#if defined(HAVE_APPINDICATOR)
 #include <libappindicator/app-indicator.h>
 #endif
 
@@ -39,31 +39,14 @@ struct ui_psensor {
 	/* mutex which MUST be used for accessing sensors.*/
 	pthread_mutex_t sensors_mutex;
 
-	GtkWidget *w_graph;
-
 	struct config *config;
 
 	GtkWidget *main_window;
 
-	GtkWidget *menu_bar;
-
 	GtkWidget *popup_menu;
 
-	/*
-	 * The main vertical box, top contains the menubar, bottom
-	 * contains the sensor_box.
-	 */
-	GtkWidget *main_box;
-
-	/*
-	 * The box which contains the sensors graph and the sensors
-	 * information list.
-	 */
-	GtkPaned *sensor_box;
-
 	GtkListStore *sensors_store;
 	GtkTreeView *sensors_tree;
-	GtkScrolledWindow *sensors_scrolled_tree;
 
 	int graph_update_interval;
 };
@@ -89,14 +72,13 @@ void ui_window_create(struct ui_psensor *ui);
 
 void ui_menu_bar_show(unsigned int show, struct ui_psensor *ui);
 
-void ui_show_about_dialog();
-
 void ui_enable_alpha_channel(struct ui_psensor *ui);
 
 void ui_cb_preferences(GtkMenuItem *mi, gpointer data);
-void ui_cb_about(GtkMenuItem *mi, gpointer data);
 void ui_cb_menu_quit(GtkMenuItem *mi, gpointer data);
 void ui_cb_sensor_preferences(GtkMenuItem *mi, gpointer data);
 
-struct psensor **ui_get_sensors_ordered_by_position(const struct ui_psensor *);
+GtkWidget *ui_get_graph(void);
+
+struct psensor **ui_get_sensors_ordered_by_position(struct psensor **);
 #endif
