@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -38,14 +38,14 @@ on_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer data)
 	struct ui_psensor *ui_psensor = (struct ui_psensor *)data;
 
 	graph_update(ui_psensor->sensors,
-		     ui_psensor->w_graph,
+		     ui_get_graph(),
 		     ui_psensor->config,
 		     ui_psensor->main_window);
 
 	return FALSE;
 }
 
-void smooth_curves_enabled_changed_cbk(void *data)
+static void smooth_curves_enabled_changed_cbk(void *data)
 {
 	is_smooth_curves_enabled = config_is_smooth_curves_enabled();
 }
@@ -56,7 +56,7 @@ void ui_graph_create(struct ui_psensor *ui)
 
 	log_debug("ui_graph_create()");
 
-	w_graph = ui->w_graph;
+	w_graph = ui_get_graph();
 
 	is_smooth_curves_enabled = config_is_smooth_curves_enabled();
 	g_signal_connect_after(config_get_GSettings(),
